@@ -1,5 +1,6 @@
 #include "connect.h"
 #include "domain.h"
+#include "domainsnapshot.h"
 #include "events.h"
 #include "interface.h"
 #include "network.h"
@@ -2002,6 +2003,7 @@ virtDBusConnectFree(virtDBusConnect *connect)
         virtDBusConnectClose(connect, TRUE);
 
     g_free(connect->domainPath);
+    g_free(connect->domainSnapshotPath);
     g_free(connect->interfacePath);
     g_free(connect->networkPath);
     g_free(connect->nodeDevPath);
@@ -2062,6 +2064,10 @@ virtDBusConnectNew(virtDBusConnect **connectp,
     if (error && *error)
         return;
 
+    virtDBusDomainSnapshotRegister(connect, error);
+    if (error && *error)
+        return;
+
     virtDBusInterfaceRegister(connect, error);
     if (error && *error)
         return;
