@@ -84,13 +84,7 @@ class BaseTestClass():
         interface_obj.Create(0)
         return path, interface_obj
 
-    @pytest.fixture
     def node_device_create(self):
-        """ Fixture to create dummy node device on the test driver
-
-        This fixture should be used in the setup of every test manipulating
-        with node devices.
-        """
         # We need a usable parent nodedev: possible candidates are
         # scsi_host2 (available since libvirt 3.1.0) and
         # test-scsi-host-vport (available until libvirt 3.0.0).
@@ -109,6 +103,27 @@ class BaseTestClass():
         path = self.connect.NodeDeviceCreateXML(xml, 0)
         return path
 
+    @pytest.fixture(name="node_device_create")
+    def fixture_node_device_create(self):
+        """ Fixture to create dummy node device on the test driver
+
+        This fixture should be used in the setup of every test manipulating
+        with node devices.
+        """
+        return self.node_device_create()
+
+    @pytest.fixture
+    def snapshot_create(self):
+        """ Fixture to create simple domain snapshot on the test driver
+
+        This fixture should be used in the setup of every test manipulating
+        with domain snaphots.
+        """
+        _, test_domain = self.get_test_domain()
+        path = test_domain.SnapshotCreateXML(xmldata.minimal_snapshot_xml, 0)
+        obj = self.bus.get_object('org.libvirt', path)
+        return dbus.Interface(obj, 'org.libvirt.DomainSnapshot')
+
     @pytest.fixture
     def storage_volume_create(self):
         """ Fixture to create dummy storage volume on the test driver
